@@ -1,5 +1,3 @@
-context("detect")
-
 y <- 4:10
 
 test_that("detect functions work", {
@@ -24,20 +22,22 @@ test_that("has_element checks whether a list contains an object", {
 })
 
 test_that("`detect()` requires a predicate function", {
-  expect_error(detect(list(1:2, 2), is.na), "must return a single `TRUE` or `FALSE`")
-  expect_error(detect(list(1:2, 2), function(...) NA), "not a missing value")
+  expect_snapshot(detect(list(1:2, 2), is.na), error = TRUE)
+  expect_snapshot(detect_index(list(1:2, 2), is.na), error = TRUE)
 })
 
 
 # Lifecycle ---------------------------------------------------------------
 
 test_that("`.right` argument is retired", {
-  scoped_lifecycle_warnings()
-  expect_warning(detect(1:2, ~ TRUE, .right = TRUE), "soft-deprecated")
+  expect_snapshot({
+    . <- detect(1:2, ~TRUE, .right = TRUE)
+    . <- detect_index(1:2, ~TRUE, .right = TRUE)
+  })
 })
 
 test_that("`.right` argument still works", {
-  scoped_lifecycle_silence()
+  local_options(lifecycle_verbosity = "quiet")
   is_odd <- function(x) x %% 2 == 1
   expect_equal(detect(y, is_odd, .right = TRUE), 9)
   expect_equal(detect_index(y, is_odd, .right = TRUE), 6)
