@@ -1,4 +1,4 @@
-x <- 1:3 %>% set_names()
+x <- 1:3 |> set_names()
 
 test_that("imap is special case of map2", {
   expect_identical(imap(x, paste), map2(x, names(x), paste))
@@ -13,6 +13,7 @@ test_that("atomic vector imap works", {
   expect_length(imap_chr(x, paste), 3)
   expect_equal(imap_int(x, ~ .x + as.integer(.y)), x * 2)
   expect_equal(imap_dbl(x, ~ .x + as.numeric(.y)), x * 2)
+  expect_equal(imap_vec(x, ~ .x + as.numeric(.y)), x * 2)
 })
 
 test_that("iwalk returns invisibly", {
